==> ifrit_3.3.4.orig.tar.gz: ifrit-3.3.4/shells/generic/iggdialoganimatingprogress.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2011 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IGGDIALOGANIMATINGPROGRESS_H
#define IGGDIALOGANIMATINGPROGRESS_H


#include "iggdialog.h"
#include "iscript.h"


class iViewModule;

class iggWidgetTextArea;

class vtkTimerLog;


class iggDialogAnimatingProgress : public iggDialog, public iScriptObserver
{

public:

	iggDialogAnimatingProgress(iggMainWindow *parent);

	virtual const iString& GetToolTip() const;

	void Animate();

	void Pause(bool s);
	inline bool IsPaused() const { return mPaused; }

	void Cancel();
	inline bool IsCancelled() const { return mCancelled; }

protected:

	virtual void OnScriptStartBody();
	virtual void OnScriptStopBody(const iString &error);
	virtual void OnScriptBeginLineBody(int line, const iString &text);
	virtual void OnScriptEndLineBody(int line, const iString &text);
	virtual bool OnScriptCheckAbortBody(int cur, int num, int level);

	void DisplayInfo();
	virtual bool CanBeClosed();

	iViewModule *mCurrentViewModule;
	bool mCancelled, mPaused;
	iggWidgetTextArea *mCurrentImageNumber, *mCurrentFrame, *mCurrentRecord, *mWarning;
	iggFrame *mInfoFrame, *mWarningFrame;
	int mLastImageIndex, mLastRecord, mLastFrame;
};

#endif  //  IGGDIALOGANIMATINGPROGRESS_H

==> ifrit_3.4.2.orig.tar.gz: ifrit-3.4.2/shells/generic/iggdialoganimatingprogress.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IGGDIALOGANIMATINGPROGRESS_H
#define IGGDIALOGANIMATINGPROGRESS_H


#include "iggdialog.h"
#include "iscript.h"


class iViewModule;

class iggWidgetTextArea;

class vtkTimerLog;


class iggDialogAnimatingProgress : public iggDialog, public iScriptObserver
{

public:

	iggDialogAnimatingProgress(iggMainWindow *parent);

	virtual const iString& GetToolTip() const;

	void Animate();

	void Pause(bool s);
	inline bool IsPaused() const { return mPaused; }

	void Cancel();
	inline bool IsCancelled() const { return mCancelled; }

protected:

	virtual void CompleteConstructionBody();

	virtual void OnScriptStartBody();
	virtual void OnScriptStopBody(const iString &error);
	virtual void OnScriptBeginLineBody(int line, const iString &text);
	virtual void OnScriptEndLineBody(int line, const iString &text);
	virtual bool OnScriptCheckAbortBody(int cur, int num, int level);

	void DisplayInfo();
	virtual bool CanBeClosed();

	iViewModule *mCurrentViewModule;
	bool mCancelled, mPaused;
	iggWidgetTextArea *mCurrentFrame, *mCurrentRecord, *mWarning;
	iggFrame *mInfoFrame, *mWarningFrame;
	int mLastRecord, mLastFrame;
};

#endif  //  IGGDIALOGANIMATINGPROGRESS_H
